<?php
/**
 * The template for adding Featured Content Settings in Customizer
 *
 * @package Catch Themes
 * @subpackage Clean Business Pro
 * @since Clean Business 1.0
 */


$wp_customize->add_panel( 'clean_business_featured_content', array(
    'capability'     => 'edit_theme_options',
	'description'    => esc_html__( 'Options for Featured Content', 'clean-business-pro' ),
    'priority'       => 500,
    'title'    		 => esc_html__( 'Featured Content', 'clean-business-pro' ),
) );

$wp_customize->add_section( 'clean_business_featured_content', array(
	'panel'			=> 'clean_business_featured_content',
	'title'			=> esc_html__( 'Featured Content Options', 'clean-business-pro' ),
) );


$wp_customize->add_setting( 'featured_content_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_option'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'featured_content_option', array(
	'choices'  => clean_business_featured_slider_content_options(),
	'label'    => esc_html__( 'Enable Featured Content on', 'clean-business-pro' ),
	'priority' => '1',
	'section'  => 'clean_business_featured_content',
	'settings' => 'featured_content_option',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'featured_content_layout', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_layout'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'featured_content_layout', array(
	'active_callback' => 'clean_business_is_featured_content_active',
	'choices'         => clean_business_featured_content_layout_options(),
	'label'           => esc_html__( 'Select Featured Content Layout', 'clean-business-pro' ),
	'priority'        => '2',
	'section'         => 'clean_business_featured_content',
	'settings'        => 'featured_content_layout',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'featured_content_position', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_position'],
	'sanitize_callback' => 'clean_business_sanitize_checkbox'
) );

$wp_customize->add_control( 'featured_content_position', array(
	'active_callback' => 'clean_business_is_featured_content_active',
	'label'           => esc_html__( 'Check to Move above Footer', 'clean-business-pro' ),
	'priority'        => '3',
	'section'         => 'clean_business_featured_content',
	'settings'        => 'featured_content_position',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'featured_content_type', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_type'],
	'sanitize_callback'	=> 'sanitize_key',
) );

$wp_customize->add_control( 'featured_content_type', array(
	'active_callback' => 'clean_business_is_featured_content_active',
	'choices'         => clean_business_featured_content_types(),
	'label'           => esc_html__( 'Select Content Type', 'clean-business-pro' ),
	'priority'        => '3',
	'section'         => 'clean_business_featured_content',
	'settings'        => 'featured_content_type',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'featured_content_headline', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_headline'],
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'featured_content_headline' , array(
	'active_callback' => 'clean_business_is_featured_content_active',
	'description'     => esc_html__( 'Leave field empty if you want to remove Headline', 'clean-business-pro' ),
	'label'           => esc_html__( 'Headline for Featured Content', 'clean-business-pro' ),
	'priority'        => '4',
	'section'         => 'clean_business_featured_content',
	'settings'        => 'featured_content_headline',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'featured_content_subheadline', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_subheadline'],
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'featured_content_subheadline' , array(
	'active_callback' => 'clean_business_is_featured_content_active',
	'description'     => esc_html__( 'Leave field empty if you want to remove Sub-headline', 'clean-business-pro' ),
	'label'           => esc_html__( 'Sub-headline for Featured Content', 'clean-business-pro' ),
	'priority'        => '5',
	'section'         => 'clean_business_featured_content',
	'settings'        => 'featured_content_subheadline',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'featured_content_number', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_number'],
	'sanitize_callback'	=> 'clean_business_sanitize_number_range',
) );

$wp_customize->add_control( 'featured_content_number' , array(
		'active_callback' => 'clean_business_is_demo_featured_content_inactive',
		'description'     => esc_html__( 'Save and refresh the page if No. of Featured Content is changed (Max no of Featured Content is 20)', 'clean-business-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 45px;',
			'min'   => 0,
			'max'   => 20,
			'step'  => 1,
		),
		'label'           => esc_html__( 'No of Featured Content', 'clean-business-pro' ),
		'priority'        => '6',
		'section'         => 'clean_business_featured_content',
		'settings'        => 'featured_content_number',
		'type'            => 'number',
	)
);

$wp_customize->add_setting( 'featured_content_show', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_show'],
	'sanitize_callback'	=> 'sanitize_key',
) );

$wp_customize->add_control( 'featured_content_show', array(
	'active_callback' => 'clean_business_is_demo_featured_content_inactive',
	'choices'         => clean_business_featured_content_show(),
	'label'           => esc_html__( 'Display Content', 'clean-business-pro' ),
	'priority'        => '6.1',
	'section'         => 'clean_business_featured_content',
	'settings'        => 'featured_content_show',
	'type'            => 'select',
) );


$wp_customize->add_setting( 'featured_content_select_category', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'clean_business_sanitize_category_list',
) );

$wp_customize->add_control( new clean_business_customize_dropdown_categories_control( $wp_customize, 'clean_business_featured_content_select_category', array(
	'active_callback' => 'clean_business_is_featured_category_content_active',
	'label'           => esc_html__( 'Select Categories', 'clean-business-pro' ),
	'name'            => 'featured_content_select_category',
	'section'         => 'clean_business_featured_content',
	'settings'        => 'featured_content_select_category',
	'type'            => 'dropdown-categories',
) ) );

$featured_content_number = apply_filters( 'clean_business_get_option', 'featured_content_number' );

//loop for featured post content
for ( $i=1; $i <=  $featured_content_number ; $i++ ) {
	$wp_customize->add_setting( 'featured_content_post_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'clean_business_sanitize_page',
	) );

	$wp_customize->add_control( 'clean_business_featured_content_post_'. $i, array(
			'active_callback' => 'clean_business_is_featured_post_content_active',
			'input_attrs'     => array(
				'style'           => 'width: 40px;'
			),
			'label'           => esc_html__( 'Featured Post', 'clean-business-pro' ) . ' ' . $i ,
			'priority'        =>  '4' . $i,
			'section'         => 'clean_business_featured_content',
			'settings'        => 'featured_content_post_'. $i,
			'type'            => 'text',
		)
	);

	$wp_customize->add_setting( 'featured_content_page_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'clean_business_sanitize_page',
	) );

	$wp_customize->add_control( 'clean_business_featured_content_page_'. $i, array(
		'active_callback' => 'clean_business_is_featured_page_content_active',
		'label'           => esc_html__( 'Featured Page', 'clean-business-pro' ) . ' ' . $i ,
		'priority'        => '5' . $i,
		'section'         => 'clean_business_featured_content',
		'settings'        => 'featured_content_page_'. $i,
		'type'            => 'dropdown-pages',
	) );

	if( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
		$priority++;

	$wp_customize->add_setting( 'featured_content_note_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new clean_business_note_control( $wp_customize, 'featured_content_note_'. $i, array(
		'active_callback' => 'clean_business_is_featured_image_content_active',
		'label'           => esc_html__( 'Featured Content #', 'clean-business-pro' ) .  $i,
		'section'         => 'clean_business_featured_content',
		'settings'        => 'featured_content_note_'. $i,
		'type'            => 'description',
	) ) );

	$wp_customize->add_setting( 'featured_content_image_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'clean_business_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'featured_content_image_'. $i , array(
		'active_callback' => 'clean_business_is_featured_image_content_active',
		'label'           => esc_html__( 'Image', 'clean-business-pro' ),
		'section'         => 'clean_business_featured_content',
		'settings'        => 'featured_content_image_'. $i,
	) ) );

	$wp_customize->add_setting( 'featured_content_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'featured_content_link_'. $i, array(
		'active_callback' => 'clean_business_is_featured_image_content_active',
		'label'           => esc_html__( 'Link', 'clean-business-pro' ),
		'section'         => 'clean_business_featured_content',
		'settings'        => 'featured_content_link_'. $i,
	) );

	$wp_customize->add_setting( 'featured_content_target_'. $i, array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'clean_business_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'featured_content_target_'. $i, array(
		'active_callback'	=> 'clean_business_is_featured_image_content_active',
		'label'		=> esc_html__( 'Check to Open Link in New Window/Tab', 'clean-business-pro' ),
        'section'   => 'clean_business_featured_content',
        'settings'  => 'featured_content_target_'. $i,
		'type'		=> 'checkbox',
    ) );

    $wp_customize->add_setting( 'featured_content_title_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'featured_content_title_'. $i, array(
		'active_callback' => 'clean_business_is_featured_image_content_active',
		'label'           => esc_html__( 'Title', 'clean-business-pro' ),
		'section'         => 'clean_business_featured_content',
		'settings'        => 'featured_content_title_'. $i,
		'type'            => 'text',
    ) );

    $wp_customize->add_setting( 'featured_content_content_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'featured_content_content_'. $i, array(
		'active_callback' => 'clean_business_is_featured_image_content_active',
		'label'           => esc_html__( 'Content', 'clean-business-pro' ),
		'section'         => 'clean_business_featured_content',
		'settings'        => 'featured_content_content_'. $i,
		'type'            => 'textarea',
    ) );
}

$wp_customize->add_section( 'clean_business_featured_content_button', array(
	'description' => esc_html__( 'Make sure Featured Content is enabled for these options to work', 'clean-business-pro' ),
	'panel'       => 'clean_business_featured_content',
	'title'       => esc_html__( 'Call To Action Button Settings', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'featured_content_button_text', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_button_text'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control(  'featured_content_button_text', array(
	'active_callback' => 'clean_business_is_featured_content_active',
	'label'           => esc_html__( 'Button Text', 'clean-business-pro' ),
	'section'         => 'clean_business_featured_content_button',
	'settings'        => 'featured_content_button_text',
) );

$wp_customize->add_setting( 'featured_content_button_link', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_button_link'],
	'sanitize_callback'	=> 'esc_url_raw',
) );

$wp_customize->add_control(  'featured_content_button_link', array(
	'active_callback' => 'clean_business_is_featured_content_active',
	'label'           => esc_html__( 'Link', 'clean-business-pro' ),
	'section'         => 'clean_business_featured_content_button',
	'settings'        => 'featured_content_button_link',
	'type'            => 'text',
) );

$wp_customize->add_setting( 'featured_content_button_target', array(
    'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['featured_content_button_target'],
	'sanitize_callback'	=> 'clean_business_sanitize_checkbox',
) );

$wp_customize->add_control(  'featured_content_button_target', array(
	'active_callback' => 'clean_business_is_featured_content_active',
	'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'clean-business-pro' ),
	'section'         => 'clean_business_featured_content_button',
	'settings'        => 'featured_content_button_target',
	'type'            => 'checkbox',
) );

$wp_customize->add_section( 'clean_business_featured_content_bg_settings', array(
	'description' => esc_html__( 'Make sure Featured Content is enabled for these options to work', 'clean-business-pro' ),
	'panel'       => 'clean_business_featured_content',
	'title'       => esc_html__( 'Featured Content Background Settings', 'clean-business-pro' ),
) );

$default_featured_content_background_color = $defaults['featured_content_background_color'];

$color_scheme	= apply_filters( 'clean_business_color_options', 'color_scheme' );

if ( 'dark' == $color_scheme ) {
	$defaults_dark = clean_business_default_dark_color_options();
	$default_featured_content_background_color = $defaults_dark['featured_content_background_color'];
}

$wp_customize->add_setting( 'featured_content_background_color', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_background_color'],
	'sanitize_callback' => 'sanitize_hex_color',
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'featured_content_background_color', array(
	'label'    => esc_html__( 'Background Color', 'clean-business-pro' ),
	'section'  => 'clean_business_featured_content_bg_settings',
	'settings' => 'featured_content_background_color',
) ) );

$wp_customize->add_setting( 'featured_content_bg_image', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_bg_image'],
	'sanitize_callback'	=> 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'featured_content_bg_image', array(
	'label'		=> esc_html__( 'Select/Add Background Image', 'clean-business-pro' ),
	'section'   => 'clean_business_featured_content_bg_settings',
    'settings'  => 'featured_content_bg_image',
) ) );

$wp_customize->add_setting( 'featured_content_bg_display_position', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_bg_display_position'],
	'sanitize_callback' => 'clean_business_sanitize_select',
) );

$wp_customize->add_control( 'featured_content_bg_display_position', array(
	'choices'  	=> clean_business_featured_content_bg_display_positions(),
	'label'    	=> esc_html__( 'Display Position', 'clean-business-pro' ),
	'section'  	=> 'clean_business_featured_content_bg_settings',
	'settings' 	=> 'featured_content_bg_display_position',
	'type'	  	=> 'radio',
) );

$wp_customize->add_setting( 'featured_content_bg_repeat', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_bg_repeat'],
	'sanitize_callback' => 'clean_business_sanitize_select',
) );

$wp_customize->add_control( 'featured_content_bg_repeat', array(
	'choices'  	=> clean_business_featured_content_bg_repeat_options(),
	'label'    	=> esc_html__( 'Repeat', 'clean-business-pro' ),
	'section'  	=> 'clean_business_featured_content_bg_settings',
	'settings' 	=> 'featured_content_bg_repeat',
	'type'	  	=> 'radio',
) );

$wp_customize->add_setting( 'featured_content_bg_attachment', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_bg_attachment'],
	'sanitize_callback' => 'clean_business_sanitize_select',
) );

$wp_customize->add_control( 'featured_content_bg_attachment', array(
	'choices'  	=> clean_business_featured_content_bg_attachment_options(),
	'label'    	=> esc_html__( 'Attachment', 'clean-business-pro' ),
	'section'  	=> 'clean_business_featured_content_bg_settings',
	'settings' 	=> 'featured_content_bg_attachment',
	'type'	  	=> 'radio',
) );