<?php
/**
 * The template for Social Links in Customizer
 *
 * @package Catch Themes
 * @subpackage Clean Business
 * @since Clean Business 1.0
 */

// Social Icons
$wp_customize->add_panel( 'clean_business_social_links', array(
    'capability'     => 'edit_theme_options',
    'description'	=> esc_html__( 'Note: Enter the url for correponding social networking website', 'clean-business-pro' ),
    'priority'       => 700,
	'title'    		 => esc_html__( 'Social Links', 'clean-business-pro' ),
) );

$wp_customize->add_section( 'clean_business_social_links', array(
	'panel'			=> 'clean_business_social_links',
	'priority' 		=> 1,
	'title'   	 	=> esc_html__( 'Social Links', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'social_icon_size', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['social_icon_size'],
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( 'social_icon_size', array(
	'input_attrs' => array(
        'min'   => 10,
        'max'   => 200,
        'step'  => 5,
        'style' => 'width: 60px;'
        ),
	'label'    	=> esc_html__( 'Social Icon Size(px)', 'clean-business-pro' ),
	'priority'	=> '1.5',
	'section' 	=> 'clean_business_social_links',
	'settings'	=> 'social_icon_size',
	'type'	   => 'number',
	)
);


$clean_business_social_icons 	=	clean_business_get_social_icons_list();

foreach ( $clean_business_social_icons as $key => $value ){
	if( 'skype_link' == $key ){
		$wp_customize->add_setting( $key, array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback' => 'esc_attr',
			) );

		$wp_customize->add_control( $key, array(
			'description'	=> esc_html__( 'Skype link can be of formats: callto://+{number} or skype:{username}?{action}. More Information in readme file', 'clean-business-pro' ),
			'label'    		=> $value['label'],
			'section'  		=> 'clean_business_social_links',
			'settings' 		=> $key,
			'type'	   		=> 'url',
		) );
	}
	else {
		if( 'email_link' == $key ){
			$wp_customize->add_setting( $key, array(
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_email',
				) );
		}
		else if( 'handset_link' == $key || 'phone_link' == $key ){
			$wp_customize->add_setting( $key, array(
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_text_field',
				) );
		}
		else {
			$wp_customize->add_setting( $key, array(
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'esc_url_raw',
				) );
		}

		$wp_customize->add_control( $key, array(
			'label'    => $value['label'],
			'section'  => 'clean_business_social_links',
			'settings' => $key,
			'type'	   => 'url',
		) );
	}
}

$wp_customize->add_section( 'clean_business_custom_social_links', array(
	'description'	=> esc_html__( 'Save and refresh the page if No. of custom social icon is changed (Max number of icons is 10)', 'clean-business-pro' ),
	'panel'			=> 'clean_business_social_links',
	'priority' 		=> 2,
	'title'   	 	=> esc_html__( 'Custom Social Links', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'custom_social_icons', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['custom_social_icons'],
	'sanitize_callback'	=> 'clean_business_sanitize_number_range',
	)
);

$wp_customize->add_control( 'custom_social_icons', array(
	'input_attrs' => array(
        'min'   => 0,
        'max'   => 10,
        'step'  => 1,
        'style' => 'width: 45px;'
        ),
	'label'    	=> esc_html__( 'Number of Custom Social Icons', 'clean-business-pro' ),
	'priority'	=> '1.5',
	'section' 	=> 'clean_business_custom_social_links',
	'settings'	=> 'custom_social_icons',
	'type'		=> 'number'
	)
);

$custom_social_icons = apply_filters( 'clean_business_get_option', 'custom_social_icons' );

//loop for custom social icons
for( $i = 1; $i <= $custom_social_icons ; $i++ ){
	if( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
		$priority++;

	$wp_customize->add_setting( 'custom_social_icon_note_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new clean_business_note_control( $wp_customize, 'custom_social_icon_note_'. $i, array(
        'label'		=> esc_html__( 'Custom Social Icon #', 'clean-business-pro' ) . $i,
		'priority'	=> $priority . '.' . $i,
        'section'  	=> 'clean_business_custom_social_links',
        'settings'	=> 'custom_social_icon_note_'. $i,
        'type'     	=> 'description',
		) ) );

		$wp_customize->add_setting( 'custom_social_icon_title_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'custom_social_icon_title_'. $i, array(
		'label'		=> esc_html__( 'Title', 'clean-business-pro' ),
		'priority'	=> $priority . '.' .$i .$i,
		'section'   => 'clean_business_custom_social_links',
		'settings'  => 'custom_social_icon_title_'. $i,
	) );

	$wp_customize->add_setting( 'custom_social_icon_image_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'clean_business_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'custom_social_icon_image_'. $i, array(
		'label'		=> esc_html__( 'Image', 'clean-business-pro' ),
        'priority'	=> $priority . '.' . $i .$i .$i,
		'section'   => 'clean_business_custom_social_links',
        'settings'  => 'custom_social_icon_image_'. $i,
	) ) );

		$wp_customize->add_setting( 'custom_social_icon_image_hover_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'clean_business_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'custom_social_icon_image_hover_'. $i , array(
		'label'		=> esc_html__( 'Hover Image(Optional)', 'clean-business-pro' ),
        'priority'	=> $priority . '.' . $i .$i . $i  .$i,
		'section'   => 'clean_business_custom_social_links',
        'settings'  => 'custom_social_icon_image_hover_'. $i,
	) ) );

	$wp_customize->add_setting( 'custom_social_icon_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'custom_social_icon_link_'. $i, array(
		'label'		=> esc_html__( 'Link', 'clean-business-pro' ),
        'priority'	=> $priority . '.' .$i . $i  . $i  .$i .$i,
		'section'   => 'clean_business_custom_social_links',
        'settings'  => 'custom_social_icon_link_'. $i,
	) );
}
// Social Icons End
