<?php
/**
 * The template for adding additional theme options in Customizer
 *
 * @package Catch Themes
 * @subpackage Clean Business Pro
 * @since Clean Business 1.0
 */

//Theme Options
$wp_customize->add_panel( 'clean_business_theme_options', array(
    'description'    => esc_html__( 'Basic theme Options', 'clean-business-pro' ),
    'capability'     => 'edit_theme_options',
    'priority'       => 200,
    'title'    		 => esc_html__( 'Theme Options', 'clean-business-pro' ),
) );

// Breadcrumb Option
$wp_customize->add_section( 'clean_business_breadcrumb_options', array(
	'description'	=> esc_html__( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'clean-business-pro' ),
	'panel'			=> 'clean_business_theme_options',
	'title'    		=> esc_html__( 'Breadcrumb Options', 'clean-business-pro' ),
	'priority' 		=> 201,
) );

$wp_customize->add_setting( 'breadcrumb_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcrumb_option'],
	'sanitize_callback' => 'clean_business_sanitize_checkbox'
) );

$wp_customize->add_control( 'breadcrumb_option', array(
	'label'    => esc_html__( 'Check to Enable Breadcrumb', 'clean-business-pro' ),
	'section'  => 'clean_business_breadcrumb_options',
	'settings' => 'breadcrumb_option',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'breadcrumb_onhomepage', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcrumb_onhomepage'],
	'sanitize_callback' => 'clean_business_sanitize_checkbox'
) );

$wp_customize->add_control( 'breadcrumb_onhomepage', array(
	'label'    => esc_html__( 'Check to enable Breadcrumb on Homepage', 'clean-business-pro' ),
	'section'  => 'clean_business_breadcrumb_options',
	'settings' => 'breadcrumb_onhomepage',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'breadcrumb_seperator', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcrumb_seperator'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'breadcrumb_seperator', array(
	'input_attrs' => array(
    		'style' => 'width: 40px;'
		),
	'label'    	=> esc_html__( 'Separator between Breadcrumbs', 'clean-business-pro' ),
	'section' 	=> 'clean_business_breadcrumb_options',
	'settings' 	=> 'breadcrumb_seperator',
	'type'     	=> 'text'
	)
);
// Breadcrumb Option End

// Comment Option
$wp_customize->add_section( 'clean_business_comment_option', array(
	'description'	=> esc_html__( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'clean-business-pro' ),
	'panel' 		=> 'clean_business_theme_options',
	'priority'		=> 202,
	'title'   		=> esc_html__( 'Comment Options', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'comment_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['comment_option'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'comment_option', array(
		'choices'  	=> clean_business_comment_options(),
		'label'		=> esc_html__( 'Comment Option', 'clean-business-pro' ),
        'priority'	=> 1,
		'section'   => 'clean_business_comment_option',
        'settings'  => 'comment_option',
        'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'disable_website_field', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_website_field'],
	'sanitize_callback' => 'clean_business_sanitize_checkbox',
) );

$wp_customize->add_control( 'disable_website_field', array(
	'label'		=> esc_html__( 'Check to Disable Website Field', 'clean-business-pro' ),
	'section'   => 'clean_business_comment_option',
    'settings'  => 'disable_website_field',
	'type'		=> 'checkbox',
) );
	// Comment End

/**
 * Do not show Custom CSS option from WordPress 4.7 onwards
 * @remove when WP 5.0 is released
 */
if ( ! function_exists( 'wp_update_custom_css_post' ) ) {
	// Custom CSS Option
	$wp_customize->add_section( 'clean_business_custom_css', array(
		'description'	=> esc_html__( 'Custom/Inline CSS', 'clean-business-pro'),
		'panel'  		=> 'clean_business_theme_options',
		'priority' 		=> 203,
		'title'    		=> esc_html__( 'Custom CSS Options', 'clean-business-pro' ),
	) );

	$wp_customize->add_setting( 'custom_css', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['custom_css'],
		'sanitize_callback' => 'clean_business_sanitize_custom_css',
	) );

	$wp_customize->add_control( 'custom_css', array(
			'label'		=> esc_html__( 'Enter Custom CSS', 'clean-business-pro' ),
	        'priority'	=> 1,
			'section'   => 'clean_business_custom_css',
	        'settings'  => 'custom_css',
			'type'		=> 'textarea',
	) );
	// Custom CSS End
}

	// Excerpt Options
$wp_customize->add_section( 'clean_business_excerpt_options', array(
	'panel'  	=> 'clean_business_theme_options',
	'priority' 	=> 204,
	'title'    	=> esc_html__( 'Excerpt Options', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'excerpt_length', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_length'],
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( 'excerpt_length', array(
	'description' => esc_html__('Excerpt length. Default is 55 words', 'clean-business-pro'),
	'input_attrs' => array(
        'min'   => 10,
        'max'   => 200,
        'step'  => 5,
        'style' => 'width: 60px;'
        ),
    'label'    => esc_html__( 'Excerpt Length (words)', 'clean-business-pro' ),
	'section'  => 'clean_business_excerpt_options',
	'settings' => 'excerpt_length',
	'type'	   => 'number',
	)
);

$wp_customize->add_setting( 'excerpt_more_text', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_more_text'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'excerpt_more_text', array(
	'label'    => esc_html__( 'Read More Text', 'clean-business-pro' ),
	'section'  => 'clean_business_excerpt_options',
	'settings' => 'excerpt_more_text',
	'type'	   => 'text',
) );
// Excerpt Options End

// Feed Redirect
$wp_customize->add_section( 'clean_business_feed_redirect', array(
	'panel'			=> 'clean_business_theme_options',
	'description'	=> esc_html__( 'If your custom feed(s) are not handled by Feedblitz or Feedburner, do not use the redirect options.', 'clean-business-pro' ),
	'priority' 		=> 205,
	'title'    		=> esc_html__( 'Feed Redirect', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'feed_redirect', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['feed_redirect'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'feed_redirect', array(
	'label'    => esc_html__( 'Feed Redirect', 'clean-business-pro' ),
	'section'  => 'clean_business_feed_redirect',
	'settings' => 'feed_redirect',
	'type'	   => 'text',
) );
// Feed Redirect End

// Font Family Options
$wp_customize->add_section( 'clean_business_font_family', array(
	'panel'  => 'clean_business_theme_options',
	'priority'	=> 206,
	'title'    	=> esc_html__( 'Font Family Options', 'clean-business-pro' ),
) );

$avaliable_fonts = clean_business_avaliable_fonts();

$choices = array();

foreach ( $avaliable_fonts as $avaliable_font ) {
	$choices[ $avaliable_font[ 'value' ] ] = str_replace( '"', '', $avaliable_font[ 'label' ] );
}

$font_family_options	=	array(
	'title_font' 		=> esc_html__( 'Site Title Font Family', 'clean-business-pro' ),
	'body_font' 		=> esc_html__( 'Default Font Family', 'clean-business-pro' ),
	'tagline_font' 		=> esc_html__( 'Site Tagline Font Family', 'clean-business-pro' ),
	'content_title_font'=> esc_html__( 'Content Title Font Family', 'clean-business-pro' ),
	'content_font' 		=> esc_html__( 'Content Body Font Family', 'clean-business-pro' ),
	'headings_font' 	=> esc_html__( 'Headings Tags from h1 to h6 Font Family', 'clean-business-pro' )
);

foreach ( $font_family_options as $key => $font_family_option ) {
	$wp_customize->add_setting( $key, array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults[ $key ],
		'sanitize_callback' => 'sanitize_key',
	) );

	$wp_customize->add_control( $key, array(
		'choices'  => $choices,
		'label'    => $font_family_option,
		'section'  => 'clean_business_font_family',
		'settings' => $key,
		'type'	   => 'select',
	) );
}

$wp_customize->add_setting( 'reset_typography', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_typography'],
	'sanitize_callback' => 'clean_business_sanitize_checkbox'
) );

$wp_customize->add_control( 'reset_typography', array(
	'label'		=> esc_html__( 'Check to reset fonts', 'clean-business-pro' ),
	'section'	=> 'clean_business_font_family',
	'settings'	=> 'reset_typography',
	'type'		=> 'checkbox',
) );
// Font Family Options End

// Footer Editor Options
$wp_customize->add_section( 'clean_business_footer_options', array(
	'description'	=> esc_html__( 'You can either add html or plain text. You can also ', 'clean-business-pro'),
	'panel'  => 'clean_business_theme_options',
	'priority' 		=> 207,
	'title'    		=> esc_html__( 'Footer Editor Options', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'footer_left_content', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['footer_left_content'],
	'sanitize_callback'	=> 'clean_business_sanitize_footer_code',
) );

$wp_customize->add_control( 'footer_left_content', array(
		'description' => esc_html__( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year] and [site-link] for current year and site link respectively.', 'clean-business-pro' ),
		'label'       => esc_html__( 'Footer Left Content', 'clean-business-pro' ),
		'section'     => 'clean_business_footer_options',
		'settings'    => 'footer_left_content',
		'type'        => 'textarea',
) );

$wp_customize->add_setting( 'footer_right_content', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['footer_right_content'],
	'sanitize_callback'	=> 'clean_business_sanitize_footer_code',
) );

$wp_customize->add_control( 'footer_right_content', array(
		'label'		=> esc_html__( 'Footer Right Content', 'clean-business-pro' ),
        'section'   => 'clean_business_footer_options',
        'settings'  => 'footer_right_content',
		'type'		=> 'textarea',
) );

$wp_customize->add_setting( 'reset_footer_content', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_footer_content'],
	'sanitize_callback' => 'clean_business_sanitize_checkbox'
) );

$wp_customize->add_control( 'reset_footer_content', array(
	'label'		=> esc_html__( 'Check to reset Footer Content', 'clean-business-pro' ),
	'settings'	=> 'reset_footer_content',
	'section'	=> 'clean_business_footer_options',
	'type'		=> 'checkbox',
) );
// Footer Options End

//Homepage / Frontpage Options
$wp_customize->add_section( 'clean_business_homepage_options', array(
	'description'	=> esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'clean-business-pro' ),
	'panel'			=> 'clean_business_theme_options',
	'priority' 		=> 209,
	'title'   	 	=> esc_html__( 'Homepage / Frontpage Options', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'front_page_category', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['front_page_category'],
	'sanitize_callback'	=> 'clean_business_sanitize_category_list',
) );

$wp_customize->add_control( new clean_business_customize_dropdown_categories_control( $wp_customize, 'front_page_category', array(
    'label'   	=> esc_html__( 'Select Categories', 'clean-business-pro' ),
    'name'	 	=> 'front_page_category',
	'priority'	=> '6',
    'section'  	=> 'clean_business_homepage_options',
    'settings' 	=> 'front_page_category',
    'type'     	=> 'dropdown-categories',
) ) );
//Homepage / Frontpage Settings End

// Layout Options
$wp_customize->add_section( 'clean_business_layout', array(
	'capability'=> 'edit_theme_options',
	'panel'		=> 'clean_business_theme_options',
	'priority'	=> 211,
	'title'		=> esc_html__( 'Layout Options', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'theme_layout', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['theme_layout'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'theme_layout', array(
	'choices'	=> clean_business_layouts(),
	'label'		=> esc_html__( 'Default Layout', 'clean-business-pro' ),
	'section'	=> 'clean_business_layout',
	'settings'   => 'theme_layout',
	'type'		=> 'select',
) );

if ( class_exists( 'woocommerce' ) ) {
	$wp_customize->add_setting( 'woocommerce_layout', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['woocommerce_layout'],
		'sanitize_callback' => 'sanitize_key',
	) );

	$wp_customize->add_control( 'woocommerce_layout', array(
		'choices'	=> clean_business_layouts(),
		'label'		=> esc_html__( 'Woocommerce Layout', 'clean-business-pro' ),
		'section'	=> 'clean_business_layout',
		'settings'   => 'woocommerce_layout',
		'type'		=> 'select',
	) );
}

$wp_customize->add_setting( 'content_layout', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['content_layout'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'content_layout', array(
	'choices'   => clean_business_get_archive_content_layout(),
	'label'		=> esc_html__( 'Archive Content Layout', 'clean-business-pro' ),
	'section'   => 'clean_business_layout',
	'settings'  => 'content_layout',
	'type'      => 'select',
) );

$wp_customize->add_setting( 'single_post_image_layout', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['single_post_image_layout'],
	'sanitize_callback' => 'sanitize_key',
) );


$wp_customize->add_control( 'single_post_image_layout', array(
		'label'		=> esc_html__( 'Single Page/Post Image Layout ', 'clean-business-pro' ),
		'section'   => 'clean_business_layout',
        'settings'  => 'single_post_image_layout',
        'type'	  	=> 'select',
		'choices'  	=> clean_business_single_post_image_layout_options()
) );
	// Layout Options End

// Pagination Options
$pagination_type = apply_filters( 'clean_business_get_option', 'pagination_type' );

$navigation_description = sprintf(
	wp_kses(
		__( '<a target="_blank" href="%1$s">WP-PageNavi Plugin</a> is recommended for Numeric Option(But will work without it).<br/>Infinite Scroll Options requires <a target="_blank" href="%2$s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'clean-business-pro' ),
		array(
			'a' => array(
				'href' => array(),
				'target' => array(),
			),
			'br'=> array()
		)
	),
	esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ),
	esc_url( 'https://wordpress.org/plugins/jetpack/' )
);

/**
* Check if navigation type is Jetpack Infinite Scroll and if it is enabled
*/
if ( ( 'infinite-scroll-click' == $pagination_type || 'infinite-scroll-scroll' == $pagination_type ) ) {
	if ( ! (class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) ) {
		$navigation_description = sprintf(
			wp_kses(
				__( 'Infinite Scroll Options requires <a target="_blank" href="%s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'clean-business-pro' ),
				array(
					'a' => array(
						'href' => array(),
						'target' => array()
					)
				)
			),
			esc_url( 'https://wordpress.org/plugins/jetpack/' )
		);
	}
	else {
		$navigation_description = '';
	}
}

$wp_customize->add_section( 'clean_business_pagination_options', array(
	'description'	=> $navigation_description,
	'panel'  		=> 'clean_business_theme_options',
	'priority'		=> 212,
	'title'    		=> esc_html__( 'Pagination Options', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'pagination_type', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['pagination_type'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'pagination_type', array(
	'choices'  => clean_business_get_pagination_types(),
	'label'    => esc_html__( 'Pagination type', 'clean-business-pro' ),
	'section'  => 'clean_business_pagination_options',
	'settings' => 'pagination_type',
	'type'	   => 'select',
) );
// Pagination Options End

//Promotion Headline Options
$wp_customize->add_section( 'clean_business_promotion_headline_options', array(
	'description'	=> esc_html__( 'To disable the fields, simply leave them empty.', 'clean-business-pro' ),
	'panel'			=> 'clean_business_theme_options',
	'priority' 		=> 213,
	'title'   	 	=> esc_html__( 'Promotion Headline Options', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'promotion_headline_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['promotion_headline_option'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'promotion_headline_option', array(
	'choices'  	=> clean_business_featured_slider_content_options(),
	'label'    	=> esc_html__( 'Enable Promotion Headline on', 'clean-business-pro' ),
	'priority'	=> '0.5',
	'section'  	=> 'clean_business_promotion_headline_options',
	'settings' 	=> 'promotion_headline_option',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'promotion_headline', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'promotion_headline', array(
	'description'	=> esc_html__( 'Appropriate Words: 10', 'clean-business-pro' ),
	'label'    	=> esc_html__( 'Promotion Headline Text', 'clean-business-pro' ),
	'priority'	=> '1',
	'section' 	=> 'clean_business_promotion_headline_options',
	'settings'	=> 'promotion_headline',
) );

$wp_customize->add_setting( 'promotion_subheadline', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_subheadline'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'promotion_subheadline', array(
	'description'	=> esc_html__( 'Appropriate Words: 15', 'clean-business-pro' ),
	'label'    	=> esc_html__( 'Promotion Subheadline Text', 'clean-business-pro' ),
	'priority'	=> '2',
	'section' 	=> 'clean_business_promotion_headline_options',
	'settings'	=> 'promotion_subheadline',
) );

$wp_customize->add_setting( 'promotion_headline_button', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_button'],
	'sanitize_callback'	=> 'sanitize_text_field'
) );

$wp_customize->add_control( 'promotion_headline_button', array(
	'description'	=> esc_html__( 'Appropriate Words: 3', 'clean-business-pro' ),
	'label'    	=> esc_html__( 'Promotion Headline Button Text ', 'clean-business-pro' ),
	'priority'	=> '3',
	'section' 	=> 'clean_business_promotion_headline_options',
	'settings'	=> 'promotion_headline_button',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'promotion_headline_url', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_url'],
	'sanitize_callback'	=> 'esc_url_raw'
) );

$wp_customize->add_control( 'promotion_headline_url', array(
	'label'    	=> esc_html__( 'Promotion Headline Link', 'clean-business-pro' ),
	'priority'	=> '4',
	'section' 	=> 'clean_business_promotion_headline_options',
	'settings'	=> 'promotion_headline_url',
	'type'		=> 'text',
) );

$wp_customize->add_setting( 'promotion_headline_target', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_target'],
	'sanitize_callback' => 'clean_business_sanitize_checkbox',
) );

$wp_customize->add_control( 'promotion_headline_target', array(
	'label'    	=> esc_html__( 'Check to Open Link in New Window/Tab', 'clean-business-pro' ),
	'priority'	=> '5',
	'section'  	=> 'clean_business_promotion_headline_options',
	'settings' 	=> 'promotion_headline_target',
	'type'     	=> 'checkbox',
) );

$wp_customize->add_setting( 'promotion_headline_left_width', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_left_width'],
	'sanitize_callback'	=> 'clean_business_sanitize_number_range'
) );

$wp_customize->add_control( 'promotion_headline_left_width', array(
'type'        	=> 'number',
'priority'   	=> '6',
'section'     	=> 'clean_business_promotion_headline_options',
'label'    		=> esc_html__( 'Promotion Headline Left Section Width', 'clean-business-pro' ),
'description'	=> esc_html__( 'This is promotion headline left section width. Once this is adjusted, the width for promotion headline right section is set automatically. in %', 'clean-business-pro' ),
'input_attrs' => array(
    'min'   => 10,
    'max'   => 100,
    'style' => 'width: 50px;'
    ),
) );
// Promotion Headline Options End

// Scrollup
$wp_customize->add_section( 'clean_business_scrollup', array(
	'panel'    => 'clean_business_theme_options',
	'priority' => 215,
	'title'    => esc_html__( 'Scrollup Options', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'disable_scrollup', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_scrollup'],
	'sanitize_callback' => 'clean_business_sanitize_checkbox',
) );

$wp_customize->add_control( 'disable_scrollup', array(
	'label'		=> esc_html__( 'Check to disable Scroll Up', 'clean-business-pro' ),
	'section'   => 'clean_business_scrollup',
    'settings'  => 'disable_scrollup',
	'type'		=> 'checkbox',
) );
// Scrollup End

// Search Options
$wp_customize->add_section( 'clean_business_search_options', array(
	'description'=> esc_html__( 'Change default placeholder text in Search.', 'clean-business-pro'),
	'panel'  => 'clean_business_theme_options',
	'priority' => 216,
	'title'    => esc_html__( 'Search Options', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'search_text', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['search_text'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'search_text', array(
	'label'		=> esc_html__( 'Default Display Text in Search', 'clean-business-pro' ),
	'section'   => 'clean_business_search_options',
    'settings'  => 'search_text',
	'type'		=> 'text',
) );
// Search Options End

// Single Post Navigation
$wp_customize->add_section( 'clean_business_single_post_navigation', array(
	'panel'  => 'clean_business_theme_options',
	'priority' => 217,
	'title'    => esc_html__( 'Single Post Navigation', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'disable_single_post_navigation', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_single_post_navigation'],
	'sanitize_callback' => 'clean_business_sanitize_checkbox',
) );

$wp_customize->add_control( 'disable_single_post_navigation', array(
	'label'		=> esc_html__( 'Check to disable Single Post Navigation', 'clean-business-pro' ),
	'section'   => 'clean_business_single_post_navigation',
    'settings'  => 'disable_single_post_navigation',
	'type'		=> 'checkbox',
) );
// Single Post Navigation End

// Update Notifier
$wp_customize->add_section( 'clean_business_disable_update_notifier', array(
	'title'    => esc_html__( 'Update Notifier', 'clean-business-pro' ),
	'priority' => 217,
	'panel'    => 'clean_business_theme_options',
) );

$wp_customize->add_setting( 'disable_update_notifier', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_update_notifier'],
	'sanitize_callback' => 'clean_business_sanitize_checkbox',
) );

$wp_customize->add_control( 'disable_update_notifier', array(
	'label'		=> esc_html__( 'Check to disable update notifications', 'clean-business-pro' ),
	'section'   => 'clean_business_disable_update_notifier',
    'settings'  => 'disable_update_notifier',
	'type'		=> 'checkbox',
) );
// Update Notifier End
//Theme Option End