<?php
/**
 * Implement Default Theme/Customizer Options
 *
 * @package Catch Themes
 * @subpackage Clean Business Pro
 * @since Clean Business Pro 1.0
 */


/**
 * Returns the default options for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_get_default_theme_options( $parameter = null ) {
	$theme_data = wp_get_theme();

	$default_theme_options = array(
		//Site Title an Tagline
		'hide_tagline'                                     => 1,
		'move_title_tagline'                               => 0,

		//Layout
		'theme_layout'                                     => 'right-sidebar',
		'woocommerce_layout'                               => 'right-sidebar',
		'content_layout'                                   => 'excerpt-image-top',
		'single_post_image_layout'                         => 'disabled',

		//Header Image
		'enable_featured_header_image'                     => 'exclude-homepage',
		'featured_header_image_position'                   => 'after_header',
		'featured_image_size'                              => 'full',
		'featured_header_image_url'                        => '',
		'featured_header_image_alt'                        => '',
		'featured_header_image_base'                       => 0,

		//Navigation
		'primary_menu_disable'                             => 0,

		//Breadcrumb Options
		'breadcrumb_option'                                => 0,
		'breadcrumb_onhomepage'                            => 0,
		'breadcrumb_seperator'                             => '&raquo;',

		//Comment Options
		'comment_option'                                   => 'use-wordpress-setting',
		'disable_website_field'                            => 0,

		//Custom CSS
		'custom_css'                                       => '',

		//Scrollup Options
		'disable_scrollup'                                 => 0,

		//Excerpt Options
		'excerpt_length'                                   => '55',
		'excerpt_more_text'                                => esc_html__( 'Read More ...', 'clean-business-pro' ),

		//Homepage / Frontpage Settings
		'front_page_category'                              => '0',

		//Pagination Options
		'pagination_type'                                  => 'default',

		//Promotion Headline Options
		'promotion_headline_option'                        => 'homepage',
		'promotion_headline_left_width'                    => '80',
		'promotion_headline'                               => esc_html__( 'Clean Business Pro is a Responsive WordPress Theme', 'clean-business-pro' ),
		'promotion_subheadline'                            => esc_html__( 'This is promotion headline. You can edit this from Appearance -> Customize -> Theme Options -> Promotion Headline Options', 'clean-business-pro' ),
		'promotion_headline_button'                        => esc_html__( 'Buy Now', 'clean-business-pro' ),
		'promotion_headline_url'                           => esc_url( 'https://catchthemes.com/' ),
		'promotion_headline_target'                        => 1,

		//Search Options
		'search_text'                                      => esc_html__( 'Search...', 'clean-business-pro' ),

		//Feed Redirect
		'feed_redirect'                                    => '',

		//Single Post Navigation
		'disable_single_post_navigation'                   => 0,

		//Font Family Options
		'body_font'                                        => 'merriweather',
		'title_font'                                       => 'sans-serif',
		'tagline_font'                                     => 'sans-serif',
		'content_title_font'                               => 'sans-serif',
		'content_font'                                     => 'sans-serif',
		'headings_font'                                    => 'lato',
		'reset_typography'                                 => 0,

		//Footer Editor Options
		'footer_left_content'                              => sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved.', '1: Year, 2: Site Title with home URL', 'clean-business-pro' ), '[the-year]', '[site-link]' ),
		'footer_right_content'                             => esc_attr( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'clean-business-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_attr( $theme_data->get( 'Author' ) ) .'</a>',
		'reset_footer_content'                             => 0,

		//Update Notifier
		'disable_update_notifier'                          => 0,

		//WooCommerce Options
		'disable_product_gallery_zoom'                     => 0,
		'disable_product_gallery_lightbox'                 => 0,
		'disable_product_gallery_slider'                   => 0,

		//Basic Color Options
		'color_scheme'                                     => 'light',
		'background_color'                                 => '#f9f9f9',
		'text_color'                                       => '#404040',
		'link_color'                                       => '#e8554e',
		'link_hover_color'                                 => '#404040',

		//Header Color Options
		'header_textcolor'                                 => '#ffffff',
		'header_background_color'                          => '',
		'site_title_hover_color'                           => '#e8554e',
		'tagline_color'                                    => '#eeeeee',

		//Primary Menu Color Options
		'menu_background_color'                            => '',
		'menu_color'                                       => '#ffffff',
		'hover_active_background_color'                    => '',
		'hover_active_text_color'                          => '#e8554e',
		'sub_menu_background_color'                        => '#1c1c1c',
		'sub_menu_text_color'                              => '#ffffff',
		'sub_menu_hover_active_background_color'           => '#e8554e',
		'sub_menu_hover_active_text_color'                 => '#ffffff',

		//Content Color Options
		'content_wrapper_background_color'                 => '#f9f9f9',
		'content_background_color'                         => '#ffffff',
		'content_border_color'                             => '#f2f2f2',
		'content_title_color'                              => '#222222',
		'content_title_hover_color'                        => '#e8554e',
		'content_meta_color'                               => '#5e5e5e',
		'content_meta_hover_color'                         => '#e8554e',

		//Sidebar Color Options
		'sidebar_background_color'                         => '#ffffff',
		'sidebar_border_color'                             => '#f2f2f2',
		'sidebar_widget_title_color'                       => '#443f3f',
		'sidebar_widget_text_color'                        => '#767676',
		'sidebar_widget_link_color'                        => '#767676',
		'sidebar_widget_link_hover_color'                  => '#e8554e',

		//Pagination Color Options
		'pagination_background_color'                      => '#ffffff',
		'pagination_border_color'                          => '#e8554e',
		'pagination_text_color'                            => '#e8554e',
		'pagination_hover_background_color'                => '#e8554e',
		'pagination_hover_border_color'                    => '#e8554e',
		'pagination_hover_text_color'                      => '#ffffff',

		//Promotion Headline Color Options
		'promotion_headline_background_color'              => '#222222',
		'promotion_headline_title_color'                   => '#ffffff',
		'promotion_headline_text_color'                    => '#ffffff',
		'promotion_headline_link_color'                    => '#e8554e',
		'promotion_headline_button_background_color'       => '#e8554e',
		'promotion_headline_button_text_color'             => '#ffffff',
		'promotion_headline_button_border_color'           => '#e8554e',
		'promotion_headline_button_hover_background_color' => '#ffffff',
		'promotion_headline_button_hover_text_color'       => '#e8554e',
		'promotion_headline_button_hover_border_color'     => '#e8554e',

		//Slider Color Options
		'slider_title_color'                               => '#ffffff',
		'slider_text_color'                                => '#ffffff',
		'slider_link_color'                                => '#e8554e',
		'slider_link_hover_color'                          => '#ffffff',
		'slider_button_background_color'                   => '',
		'slider_button_border_color'                       => '#ffffff',
		'slider_button_text_color'                         => '#ffffff',
		'slider_button_hover_background_color'             => '#e8554e',
		'slider_button_hover_border_color'                 => '#e8554e',
		'slider_button_hover_text_color'                   => '#ffffff',

		//Featured Content Color Options
		'featured_content_background_color'                => '#ffffff',
		'featured_content_title_color'                     => '#443f3f',
		'featured_content_title_hover_color'               => '#e8554e',
		'featured_content_text_color'                      => '#404040',
		'featured_content_link_color'                      => '#e8554e',
		'featured_content_link_hover_color'                => '#404040',
		'featured_content_button_background_color'         => '#e8554e',
		'featured_content_button_text_color'               => '#ffffff',
		'featured_content_button_border_color'             => '#e8554e',
		'featured_content_button_hover_background_color'   => '#ffffff',
		'featured_content_button_hover_text_color'         => '#e8554e',
		'featured_content_button_hover_border_color'       => '#e8554e',

		//Footer Color Options
		'footer_sidebar_background_color'                  => '#252525',
		'footer_sidebar_title_color'                       => '#c5c5c5',
		'footer_sidebar_text_color'                        => '#767676',
		'footer_sidebar_link_color'                        => '#767676',
		'footer_sidebar_link_hover_color'                  => '#e8554e',
		'footer_background_color'                          => '#1c1c1c',
		'footer_text_color'                                => '#888888',
		'footer_link_color'                                => '#888888',
		'footer_link_hover_color'                          => '#e8554e',

		//Scrollup Color Options
		'scrollup_background_color'                        => '#ffffff',
		'scrollup_border_color'                            => '#e8554e',
		'scrollup_text_color'                              => '#e8554e',
		'scrollup_hover_background_color'                  => '#e8554e',
		'scrollup_hover_border_color'                      => '#e8554e',
		'scrollup_hover_text_color'                        => '#ffffff',

		//Featured Content Options
		'featured_content_option'                          => 'homepage',
		'featured_content_layout'                          => 'layout-four',
		'featured_content_position'                        => 0,
		'featured_content_headline'                        => '',
		'featured_content_subheadline'                     => '',
		'featured_content_type'                            => 'demo-featured-content',
		'featured_content_number'                          => '3',
		'featured_content_select_category'                 => '0',
		'featured_content_show'                            => 'excerpt',

		'featured_content_button_text'                     => esc_html__( 'View More', 'clean-business-pro' ),
		'featured_content_button_link'                     => '#',
		'featured_content_button_target'                   => 0,

		'featured_content_bg_image'                        => trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/default_bg.jpg',
		'featured_content_bg_display_position'             => 'bottom',
		'featured_content_bg_repeat'                       => 'no-repeat',
		'featured_content_bg_attachment'                   => 'fixed',
		//Featured Slider Options
		'featured_slider_option'                           => 'homepage',
		'featured_slider_image_loader'                     => 'true',
		'featured_slider_transition_effect'                => 'fade',
		'featured_slider_speed'                            => '4',
		'featured_slider_type'                             => 'demo-featured-slider',
		'featured_slider_number'                           => '4',
		'featured_slider_select_category'                  => '0',
		'exclude_slider_post'                              => 0,

		//Social Links
		'social_icon_size'                                 => '20',
		'custom_social_icons'                              => '1',

		//Reset all settings
		'reset_all_settings'                               => 0,
	);

	if ( null == $parameter ) {
		return apply_filters( 'clean_business_default_theme_options', $default_theme_options );
	}
	else {
		if ( isset( $default_theme_options[ $parameter ] ) ) {
			return $default_theme_options[ $parameter ];
		};

		return false;
	}
}


/**
 * Returns the default options for Clean Business dark theme.
 *
 * @since Catchresponsive 1.0
 */
function clean_business_default_dark_color_options() {
	$default_dark_color_options = array(
		//Basic Color Options
		'background_color'                                 => '#333333',
		'text_color'                                       => '#bebebe',
		'link_color'                                       => '#e8554e',
		'link_hover_color'                                 => '#eeeeee',

		//Header Color Options
		'header_textcolor'                                 => '#ffffff',
		'header_background_color'                          => '',
		'site_title_hover_color'                           => '#e8554e',
		'tagline_color'                                    => '#eeeeee',

		//Content Color Options
		'content_wrapper_background_color'                 => '#333333',
		'content_background_color'                         => '#1b1b1b',
		'content_border_color'                             => '#444444',
		'content_title_color'                              => '#dddddd',
		'content_title_hover_color'                        => '#e8554e',
		'content_meta_color'                               => '#bebebe',
		'content_meta_hover_color'                         => '#e8554e',

		//Sidebar Color Options
		'sidebar_background_color'                         => '#1b1b1b',
		'sidebar_border_color'                             => '#444444',
		'sidebar_widget_title_color'                       => '#dddddd',
		'sidebar_widget_text_color'                        => '#bebebe',
		'sidebar_widget_link_color'                        => '#999999',
		'sidebar_widget_link_hover_color'                  => '#e8554e',

		//Pagination Color Options
		'pagination_background_color'                      => '#333333',
		'pagination_border_color'                          => '#e8554e',
		'pagination_text_color'                            => '#e8554e',
		'pagination_hover_background_color'                => '#e8554e',
		'pagination_hover_border_color'                    => '#e8554e',
		'pagination_hover_text_color'                      => '#ffffff',

		//Footer Color Options
		'footer_sidebar_background_color'                  => '#252525',
		'footer_sidebar_title_color'                       => '#c5c5c5',
		'footer_sidebar_text_color'                        => '#bebebe',
		'footer_sidebar_link_color'                        => '#999999',
		'footer_sidebar_link_hover_color'                  => '#e8554e',
		'footer_background_color'                          => '#1c1c1c',
		'footer_text_color'                                => '#888888',
		'footer_link_color'                                => '#888888',
		'footer_link_hover_color'                          => '#e8554e',

		//Promotion Headline Color Options
		'promotion_headline_background_color'              => '#111111',
		'promotion_headline_title_color'                   => '#ffffff',
		'promotion_headline_text_color'                    => '#ffffff',
		'promotion_headline_link_color'                    => '#e8554e',
		'promotion_headline_button_background_color'       => '#e8554e',
		'promotion_headline_button_text_color'             => '#ffffff',
		'promotion_headline_button_border_color'           => '#e8554e',
		'promotion_headline_button_hover_background_color' => '#ffffff',
		'promotion_headline_button_hover_text_color'       => '#e8554e',
		'promotion_headline_button_hover_border_color'     => '#e8554e',

		//Scrollup Color Options
		'scrollup_background_color'                        => '#333333',
		'scrollup_border_color'                            => '#e8554e',
		'scrollup_text_color'                              => '#e8554e',
		'scrollup_hover_background_color'                  => '#e8554e',
		'scrollup_hover_border_color'                      => '#e8554e',
		'scrollup_hover_text_color'                        => '#ffffff',

		//Slider Color Options
		'slider_title_color'                               => '#ffffff',
		'slider_text_color'                                => '#ffffff',
		'slider_link_color'                                => '#e8554e',
		'slider_link_hover_color'                          => '#ffffff',
		'slider_button_background_color'                   => '',
		'slider_button_border_color'                       => '#ffffff',
		'slider_button_text_color'                         => '#ffffff',
		'slider_button_hover_background_color'             => '#e8554e',
		'slider_button_hover_border_color'                 => '#e8554e',
		'slider_button_hover_text_color'                   => '#ffffff',

		//Featured Content Color Options
		'featured_content_background_color'                => '#1b1b1b',
		'featured_content_title_color'                     => '#e8554e',
		'featured_content_title_hover_color'               => '#ffffff',
		'featured_content_text_color'                      => '#bebebe',
		'featured_content_link_color'                      => '#e8554e',
		'featured_content_link_hover_color'                => '#eeeeee',
		'featured_content_button_background_color'         => '#e8554e',
		'featured_content_button_text_color'               => '#ffffff',
		'featured_content_button_border_color'             => '#e8554e',
		'featured_content_button_hover_background_color'   => '#ffffff',
		'featured_content_button_hover_text_color'         => '#e8554e',
		'featured_content_button_hover_border_color'       => '#e8554e',

		//Primary Menu Color Options
		'menu_background_color'                            => '',
		'menu_color'                                       => '#ffffff',
		'hover_active_background_color'                    => '',
		'hover_active_text_color'                          => '#e8554e',
		'sub_menu_background_color'                        => '#1c1c1c',
		'sub_menu_text_color'                              => '#ffffff',
		'sub_menu_hover_active_background_color'           => '#e8554e',
		'sub_menu_hover_active_text_color'                 => '#ffffff',
	);

	return apply_filters( 'clean_business_default_dark_color_options', $default_dark_color_options );
}


/**
 * Returns list of basic color options currently supported
 *
 * @since Clean Business Pro 1.0
*/
function clean_business_get_color_options( $filter ) {
	$options = array(); // Initialize options
	switch ( $filter ) {
		case 'color_headings':
			$options = array(
				'basic_color'              => esc_html__( 'Basic Color', 'clean-business-pro' ),
				'header_color'             => esc_html__( 'Header Color', 'clean-business-pro' ),
				'menu_color'               => esc_html__( 'Primary Menu Color', 'clean-business-pro' ),
				'content_color'            => esc_html__( 'Content Color', 'clean-business-pro' ),
				'sidebar_color'            => esc_html__( 'Sidebar Color', 'clean-business-pro' ),
				'pagination_color'         => esc_html__( 'Pagination Color', 'clean-business-pro' ),
				'promotion_headline_color' => esc_html__( 'Promotion Headline Color', 'clean-business-pro' ),
				'slider_color'             => esc_html__( 'Slider Color', 'clean-business-pro' ),
				'featured_content_color'   => esc_html__( 'Featured Content Color', 'clean-business-pro' ),
				'footer_color'             => esc_html__( 'Footer Color', 'clean-business-pro' ),
				'scrollup_color'           => esc_html__( 'Scrollup Color', 'clean-business-pro' ),
			);
			break;

		case 'basic_color':
			$options =	array(
				'text_color'       => esc_html__( 'Text Color', 'clean-business-pro' ),
				'link_color'       => esc_html__( 'Link Color', 'clean-business-pro' ),
				'link_hover_color' => esc_html__( 'Link Hover Color', 'clean-business-pro' ),
			);
			break;

		case 'header_color':
			$options = array(
				'header_background_color' => esc_html__( 'Header Background color', 'clean-business-pro' ),
				'site_title_hover_color'  => esc_html__( 'Site Title Hover Color', 'clean-business-pro' ),
				'tagline_color'           => esc_html__( 'Tagline Color', 'clean-business-pro' )
			);
			break;

		case 'content_color':
			$options =	array(
					'content_wrapper_background_color' => esc_html__( 'Wrapper Background Color', 'clean-business-pro' ),
					'content_background_color'         => esc_html__( 'Background Color', 'clean-business-pro' ),
					'content_border_color'             => esc_html__( 'Border Color', 'clean-business-pro' ),
					'content_title_color'              => esc_html__( 'Title Color', 'clean-business-pro' ),
					'content_title_hover_color'        => esc_html__( 'Title Hover Color', 'clean-business-pro' ),
					'content_meta_color'               => esc_html__( 'Meta Color', 'clean-business-pro' ),
					'content_meta_hover_color'         => esc_html__( 'Meta Hover Color', 'clean-business-pro' ),
				);
				break;

		case 'sidebar_color':
			$options = array(
				'sidebar_background_color'        => esc_html__( 'Background Color', 'clean-business-pro' ),
				'sidebar_border_color'            => esc_html__( 'Border Color', 'clean-business-pro' ),
				'sidebar_widget_title_color'      => esc_html__( 'Widget Title Color', 'clean-business-pro' ),
				'sidebar_widget_text_color'       => esc_html__( 'Widget Text Color', 'clean-business-pro' ),
				'sidebar_widget_link_color'       => esc_html__( 'Widget Link Color', 'clean-business-pro' ),
				'sidebar_widget_link_hover_color' => esc_html__( 'Widget Link Hover Color', 'clean-business-pro' ),
			);
			break;

		case 'pagination_color':
			$options = array(
				'pagination_background_color'       => esc_html__( 'Background Color', 'clean-business-pro' ),
				'pagination_border_color'           => esc_html__( 'Border Color', 'clean-business-pro' ),
				'pagination_text_color'             => esc_html__( 'Text Color', 'clean-business-pro' ),
				'pagination_hover_background_color' => esc_html__( 'Hover Background Color', 'clean-business-pro' ),
				'pagination_hover_border_color'     => esc_html__( 'Hover Border Color', 'clean-business-pro' ),
				'pagination_hover_text_color'       => esc_html__( 'Hover Text Color', 'clean-business-pro' ),
			);
			break;

		case 'footer_color':
			$options = array(
				'footer_sidebar_background_color' => esc_html__( 'Sidebar Background Color', 'clean-business-pro' ),
				'footer_sidebar_title_color'      => esc_html__( 'Sidebar Title Color', 'clean-business-pro' ),
				'footer_sidebar_text_color'       => esc_html__( 'Sidebar Text Color', 'clean-business-pro' ),
				'footer_sidebar_link_color'       => esc_html__( 'Sidebar Link Color', 'clean-business-pro' ),
				'footer_sidebar_link_hover_color' => esc_html__( 'Sidebar Link Hover Color', 'clean-business-pro' ),
				'footer_background_color'         => esc_html__( 'Footer Background Color', 'clean-business-pro' ),
				'footer_text_color'               => esc_html__( 'Footer Text Color', 'clean-business-pro' ),
				'footer_link_color'               => esc_html__( 'Footer Link Color', 'clean-business-pro' ),
				'footer_link_hover_color'         => esc_html__( 'Footer Link Hover Color', 'clean-business-pro' ),
			);
			break;

		case 'promotion_headline_color':
			$options = array(
				'promotion_headline_background_color'              => esc_html__( 'Background Color', 'clean-business-pro' ),
				'promotion_headline_title_color'                   => esc_html__( 'Title Color', 'clean-business-pro' ),
				'promotion_headline_text_color'                    => esc_html__( 'Text Color', 'clean-business-pro' ),
				'promotion_headline_link_color'                    => esc_html__( 'Link Color', 'clean-business-pro' ),
				'promotion_headline_button_background_color'       => esc_html__( 'Button Background Color', 'clean-business-pro' ),
				'promotion_headline_button_text_color'             => esc_html__( 'Button Text Color', 'clean-business-pro' ),
				'promotion_headline_button_border_color'           => esc_html__( 'Button Border Color', 'clean-business-pro' ),
				'promotion_headline_button_hover_background_color' => esc_html__( 'Button Hover Background Color', 'clean-business-pro' ),
				'promotion_headline_button_hover_text_color'       => esc_html__( 'Button Hover Text Color', 'clean-business-pro' ),
				'promotion_headline_button_hover_border_color'     => esc_html__( 'Button Hover Border Color', 'clean-business-pro' ),
			);
			break;

		case 'scrollup_color':
			$options = array(
				'scrollup_background_color'       => esc_html__( 'Background Color', 'clean-business-pro' ),
				'scrollup_border_color'           => esc_html__( 'Border Color', 'clean-business-pro' ),
				'scrollup_text_color'             => esc_html__( 'Text Color', 'clean-business-pro' ),
				'scrollup_hover_background_color' => esc_html__( 'Hover Background Color', 'clean-business-pro' ),
				'scrollup_hover_border_color'     => esc_html__( 'Hover Border Color', 'clean-business-pro' ),
				'scrollup_hover_text_color'       => esc_html__( 'Hover Text Color', 'clean-business-pro' ),
			);
			break;

		case 'slider_color':
			$options = array(
				'slider_title_color'                   => esc_html__( 'Title Color', 'clean-business-pro' ),
				'slider_text_color'                    => esc_html__( 'Text Color', 'clean-business-pro' ),
				'slider_link_color'                    => esc_html__( 'Link Color', 'clean-business-pro' ),
				'slider_link_hover_color'              => esc_html__( 'Link Hover Color', 'clean-business-pro' ),
				'slider_button_background_color'       => esc_html__( 'Button Background Color', 'clean-business-pro' ),
				'slider_button_border_color'           => esc_html__( 'Button Border Color', 'clean-business-pro' ),
				'slider_button_text_color'             => esc_html__( 'Button Text Color', 'clean-business-pro' ),
				'slider_button_hover_background_color' => esc_html__( 'Button Hover Background Color', 'clean-business-pro' ),
				'slider_button_hover_border_color'     => esc_html__( 'Button Hover Border Color', 'clean-business-pro' ),
				'slider_button_hover_text_color'       => esc_html__( 'Button Hover Text Color', 'clean-business-pro' ),
			);
			break;

		case 'featured_content_color':
			$options = array(
				'featured_content_title_color'                   => esc_html__( 'Title Color', 'clean-business-pro' ),
				'featured_content_title_hover_color'             => esc_html__( 'Title Hover Color', 'clean-business-pro' ),
				'featured_content_text_color'                    => esc_html__( 'Text Color', 'clean-business-pro' ),
				'featured_content_link_color'                    => esc_html__( 'Link Color', 'clean-business-pro' ),
				'featured_content_link_hover_color'              => esc_html__( 'Link Hover Color', 'clean-business-pro' ),
				'featured_content_button_background_color'       => esc_html__( 'Button Background Color', 'clean-business-pro' ),
				'featured_content_button_text_color'             => esc_html__( 'Button Text Color', 'clean-business-pro' ),
				'featured_content_button_border_color'           => esc_html__( 'Button Border Color', 'clean-business-pro' ),
				'featured_content_button_hover_background_color' => esc_html__( 'Button Hover Background Color', 'clean-business-pro' ),
				'featured_content_button_hover_text_color'       => esc_html__( 'Button Hover Text Color', 'clean-business-pro' ),
				'featured_content_button_hover_border_color'     => esc_html__( 'Button Hover Border Color', 'clean-business-pro' ),
			);
			break;

		case 'menu_color':
			$options = array(
				'menu_background_color'                  => esc_html__( 'Menu Background color', 'clean-business-pro' ),
				'menu_color'                             => esc_html__( 'Menu Color', 'clean-business-pro' ),
				'hover_active_background_color'          => esc_html__( 'Hover Active Background Color', 'clean-business-pro' ),
				'hover_active_text_color'                => esc_html__( 'Hover Active Text Color', 'clean-business-pro' ),
				'sub_menu_background_color'              => esc_html__( 'Sub Menu Background Color', 'clean-business-pro' ),
				'sub_menu_text_color'                    => esc_html__( 'Sub Menu Text Color', 'clean-business-pro' ),
				'sub_menu_hover_active_background_color' => esc_html__( 'Sub Menu Hover/Active Background Color', 'clean-business-pro' ),
				'sub_menu_hover_active_text_color'       => esc_html__( 'Sub Menu Hover/Active Text Color', 'clean-business-pro' ),
			);
			break;
	}

	return $options;
}
add_filter( 'clean_business_color_options', 'clean_business_get_color_options' );


/**
 * Returns an array of color schemes registered for Clean Business.
 *
 * @since Clean Business 1.0
 */
function clean_business_color_schemes() {
	$options= array(
		'light'    => esc_html__( 'Light', 'clean-business-pro' ),
		'dark'     => esc_html__( 'Dark', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_color_schemes', $options );
}


/**
 * Returns an array of feature header enable options
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_enable_featured_header_image_options() {
	$options = array(
		'homepage'               => esc_html__( 'Homepage / Frontpage', 'clean-business-pro' ),
		'exclude-homepage'       => esc_html__( 'Excluding Homepage', 'clean-business-pro' ),
		'exclude-home-page-post' => esc_html__( 'Excluding Homepage, Page/Post Featured Image', 'clean-business-pro' ),
		'entire-site'            => esc_html__( 'Entire Site', 'clean-business-pro' ),
		'entire-site-page-post'  => esc_html__( 'Entire Site, Page/Post Featured Image', 'clean-business-pro' ),
		'pages-posts'            => esc_html__( 'Pages and Posts', 'clean-business-pro' ),
		'disabled'               => esc_html__( 'Disabled', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_enable_featured_header_image_options', $options );
}


/**
 * Returns an array of feature header image positions
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_featured_header_image_position_options() {
	$options = array(
		'after_header'  => esc_html__( 'After Header (Before Slider)', 'clean-business-pro' ),
		'after_slider'  => esc_html__( 'After Slider', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_featured_header_image_position_options', $options );
}


/**
 * Returns an array of layout options registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_layouts() {
	$options = array(
		'left-sidebar'          => esc_html__( 'Primary Sidebar, Content', 'clean-business-pro' ),
		'right-sidebar'         => esc_html__( 'Content, Primary Sidebar', 'clean-business-pro' ),
		'no-sidebar'            => esc_html__( 'No Sidebar ( Content Width )', 'clean-business-pro' ),
		'no-sidebar-full-width' => esc_html__( 'No Sidebar ( Full Width )', 'clean-business-pro' ),
	);
	return apply_filters( 'clean_business_layouts', $options );
}

/**
 * Returns an array of content layout options registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_get_archive_content_layout() {
	$options = array(
		'excerpt-image-left'  => esc_html__( 'Excerpt Image Left', 'clean-business-pro' ),
		'excerpt-image-right' => esc_html__( 'Excerpt Image Right', 'clean-business-pro' ),
		'excerpt-image-top'   => esc_html__( 'Excerpt Image Top', 'clean-business-pro' ),
		'full-content'        => esc_html__( 'Show Full Content (No Featured Image)', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_get_archive_content_layout', $options );
}


/**
 * Returns an array of feature image size
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_featured_image_size_options() {
	$all_sizes = clean_business_get_additional_image_sizes();

	foreach ($all_sizes as $key => $value) {
		$options[$key] = esc_html( $key ).' ('.$value['width'].'x'.$value['height'].')';
	}

	$options['full']     = esc_html__( 'Full size', 'clean-business-pro' );

	return apply_filters( 'clean_business_featured_image_size_options', $options );
}


/**
 * Returns an array of pagination schemes registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_get_pagination_types() {
	$options = array(
		'default'                => esc_html__( 'Default(Older Posts/Newer Posts)', 'clean-business-pro' ),
		'numeric'                => esc_html__( 'Numeric', 'clean-business-pro' ),
		'infinite-scroll-click'  => esc_html__( 'Infinite Scroll (Click)', 'clean-business-pro' ),
		'infinite-scroll-scroll' => esc_html__( 'Infinite Scroll (Scroll)', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_get_pagination_types', $options );
}


/**
 * Returns an array of content featured image size.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_single_post_image_layout_options() {
	$all_sizes = clean_business_get_additional_image_sizes();

	foreach ($all_sizes as $key => $value) {
		$options[$key] = esc_html( $key ).' ('.$value['width'].'x'.$value['height'].')';
	}

	$options['disabled'] = esc_html__( 'Disabled', 'clean-business-pro' );
	$options['full']     = esc_html__( 'Full size', 'clean-business-pro' );

	return apply_filters( 'clean_business_single_post_image_layout_options', $options );
}


/**
 * Returns an array of comment options for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_comment_options() {
	$options = array(
		'use-wordpress-setting' => esc_html__( 'Use WordPress Setting', 'clean-business-pro' ),
		'disable-in-pages'      => esc_html__( 'Disable in Pages', 'clean-business-pro' ),
		'disable-completely'    => esc_html__( 'Disable Completely', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_comment_options', $options );
}


/**
 * Returns an array of avaliable fonts registered for fabulous fluid
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_avaliable_fonts() {
	$avaliable_fonts = array(
		'arial-black' => array(
			'value' => 'arial-black',
			'label' => '"Arial Black", Gadget, sans-serif',
		),
		'allan' => array(
			'value' => 'allan',
			'label' => '"Allan", sans-serif',
		),
		'allerta' => array(
			'value' => 'allerta',
			'label' => '"Allerta", sans-serif',
		),
		'amaranth' => array(
			'value' => 'amaranth',
			'label' => '"Amaranth", sans-serif',
		),
		'arial' => array(
			'value' => 'arial',
			'label' => 'Arial, Helvetica, sans-serif',
		),
		'bitter' => array(
			'value' => 'bitter',
			'label' => '"Bitter", sans-serif',
		),
		'cabin' => array(
			'value' => 'cabin',
			'label' => '"Cabin", sans-serif',
		),
		'cantarell' => array(
			'value' => 'cantarell',
			'label' => '"Cantarell", sans-serif',
		),
		'century-gothic' => array(
			'value' => 'century-gothic',
			'label' => '"Century Gothic", sans-serif',
		),
		'courier-new' => array(
			'value' => 'courier-new',
			'label' => '"Courier New", Courier, monospace',
		),
		'crimson-text' => array(
			'value' => 'crimson-text',
			'label' => '"Crimson Text", sans-serif',
		),
		'cuprum' => array(
			'value' => 'cuprum',
			'label' => '"Cuprum", sans-serif',
		),
		'dancing-script' => array(
			'value' => 'dancing-script',
			'label' => '"Dancing Script", sans-serif',
		),
		'droid-sans' => array(
			'value' => 'droid-sans',
			'label' => '"Droid Sans", sans-serif',
		),
		'droid-serif' => array(
			'value' => 'droid-serif',
			'label' => '"Droid Serif", sans-serif',
		),
		'exo' => array(
			'value' => 'exo',
			'label' => '"Exo", sans-serif',
		),
		'exo-2' => array(
			'value' => 'exo-2',
			'label' => '"Exo 2", sans-serif',
		),
		'georgia' => array(
			'value' => 'georgia',
			'label' => 'Georgia, "Times New Roman", Times, serif',
		),
		'helvetica' => array(
			'value' => 'helvetica',
			'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
		),
		'helvetica-neue' => array(
			'value' => 'helvetica-neue',
			'label' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
		),
		'istok-web' => array(
			'value' => 'istok-web',
			'label' => '"Istok Web", sans-serif',
		),
		'impact' => array(
			'value' => 'impact',
			'label' => 'Impact, Charcoal, sans-serif',
		),
		'josefin-sans' => array(
			'value' => 'josefin-sans',
			'label' => '"Josefin Sans", sans-serif',
		),
		'lato' => array(
			'value' => 'lato',
			'label' => '"Lato", sans-serif',
		),
		'lucida-sans-unicode' => array(
			'value' => 'lucida-sans-unicode',
			'label' => '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
		),
		'lucida-grande' => array(
			'value' => 'lucida-grande',
			'label' => '"Lucida Grande", "Lucida Sans Unicode", sans-serif',
		),
		'lobster' => array(
			'value' => 'lobster',
			'label' => '"Lobster", sans-serif',
		),
		'lora' => array(
			'value' => 'lora',
			'label' => '"Lora", serif',
		),
		'merriweather' => array(
			'value' => 'merriweather',
			'label' => 'Merriweather, sans-serif',
		),
		'monaco' => array(
			'value' => 'monaco',
			'label' => 'Monaco, Consolas, "Lucida Console", monospace, sans-serif',
		),
		'montserrat' => array(
			'value' => 'montserrat',
			'label' => '"Montserrat", sans-serif',
		),
		'nobile' => array(
			'value' => 'nobile',
			'label' => '"Nobile", sans-serif',
		),
		'noto-serif' => array(
			'value' => 'noto-serif',
			'label' => '"Noto Serif", serif',
		),
		'neuton' => array(
			'value' => 'neuton',
			'label' => '"Neuton", serif',
		),
		'open-sans' => array(
			'value' => 'open-sans',
			'label' => '"Open Sans", sans-serif',
		),
		'oswald' => array(
			'value' => 'oswald',
			'label' => '"Oswald", sans-serif',
		),
		'palatino' => array(
			'value' => 'palatino',
			'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
		),
		'patua-one' => array(
			'value' => 'patua-one',
			'label' => '"Patua One", sans-serif',
		),
		'playfair-display' => array(
			'value' => 'playfair-display',
			'label' => '"Playfair Display", sans-serif',
		),
		'pt-sans' => array(
			'value' => 'pt-sans',
			'label' => '"PT Sans", sans-serif',
		),
		'pt-serif' => array(
			'value' => 'pt-serif',
			'label' => '"PT Serif", serif',
		),
		'quattrocento-sans' => array(
			'value' => 'quattrocento-sans',
			'label' => '"Quattrocento Sans", sans-serif',
		),
		'roboto' => array(
			'value' => 'roboto',
			'label' => '"Roboto", sans-serif',
		),
		'roboto-slab' => array(
			'value' => 'roboto-slab',
			'label' => '"Roboto Slab", serif',
		),
		'sans-serif' => array(
			'value' => 'sans-serif',
			'label' => 'Sans Serif, Arial',
		),
		'source-sans-pro' => array(
			'value' => 'source-sans-pro',
			'label' => '"Source Sans Pro", sans-serif',
		),
		'tahoma' => array(
			'value' => 'tahoma',
			'label' => 'Tahoma, Geneva, sans-serif',
		),
		'trebuchet-ms' => array(
			'value' => 'trebuchet-ms',
			'label' => '"Trebuchet MS", "Helvetica", sans-serif',
		),
		'times-new-roman' => array(
			'value' => 'times-new-roman',
			'label' => '"Times New Roman", Times, serif',
		),
		'ubuntu' => array(
			'value' => 'ubuntu',
			'label' => '"Ubuntu", sans-serif',
		),
		'varela' => array(
			'value' => 'varela',
			'label' => '"Varela", sans-serif',
		),
		'verdana' => array(
			'value' => 'verdana',
			'label' => 'Verdana, Geneva, sans-serif',
		),
		'yanone-kaffeesatz' => array(
			'value' => 'yanone-kaffeesatz',
			'label' => '"Yanone Kaffeesatz", sans-serif',
		),
	);

	return apply_filters( 'clean_business_avaliable_fonts', $avaliable_fonts );
}


/**
 * Returns an array of metabox layout options registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_metabox_layouts() {
	$options = array(
		'default' 	=> array(
			'id' 	=> 'clean-business-layout-option',
			'value' => 'default',
			'label' => esc_html__( 'Default', 'clean-business-pro' ),
		),
		'left-sidebar' 	=> array(
			'id' 	=> 'clean-business-layout-option',
			'value' => 'left-sidebar',
			'label' => esc_html__( 'Primary Sidebar, Content', 'clean-business-pro' ),
		),
		'right-sidebar' => array(
			'id' 	=> 'clean-business-layout-option',
			'value' => 'right-sidebar',
			'label' => esc_html__( 'Content, Primary Sidebar', 'clean-business-pro' ),
		),
		'no-sidebar'	=> array(
			'id' 	=> 'clean-business-layout-option',
			'value' => 'no-sidebar',
			'label' => esc_html__( 'No Sidebar ( Content Width )', 'clean-business-pro' ),
		),
		'no-sidebar-full-width' => array(
			'id' 	=> 'clean-business-layout-option',
			'value' => 'no-sidebar-full-width',
			'label' => esc_html__( 'No Sidebar ( Full Width )', 'clean-business-pro' ),
		),
	);
	return apply_filters( 'clean_business_layouts', $options );
}

/**
 * Returns an array of metabox header featured image options registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_metabox_header_featured_image_options() {
	$options = array(
		'default' => array(
			'id'		=> 'clean-business-header-image',
			'value' 	=> 'default',
			'label' 	=> esc_html__( 'Default', 'clean-business-pro' ),
		),
		'enable' => array(
			'id'		=> 'clean-business-header-image',
			'value' 	=> 'enable',
			'label' 	=> esc_html__( 'Enable', 'clean-business-pro' ),
		),
		'disabled' => array(
			'id'		=> 'clean-business-header-image',
			'value' 	=> 'disabled',
			'label' 	=> esc_html__( 'Disable', 'clean-business-pro' )
		)
	);
	return apply_filters( 'header_featured_image_options', $options );
}


/**
 * Returns an array of metabox sidebar options registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_metabox_sidebar_options() {
	$options = array(
		'main-sidebar' => array(
			'id'		=> 'clean-business-sidebar-options',
			'value' 	=> 'default-sidebar',
			'label' 	=> esc_html__( 'Default Sidebar', 'clean-business-pro' )
		),
		'optional-sidebar-one' => array(
			'id' 	=> 'clean-business-sidebar-options',
			'value' => 'optional-sidebar-one',
			'label' => esc_html__( 'Optional Sidebar One', 'clean-business-pro' )
		),
		'optional-sidebar-two' => array(
			'id' 	=> 'clean-business-sidebar-options',
			'value' => 'optional-sidebar-two',
			'label' => esc_html__( 'Optional Sidebar Two', 'clean-business-pro' )
		),
		'optional-sidebar-three' => array(
			'id' 	=> 'clean-business-sidebar-options',
			'value' => 'optional-sidebar-three',
			'label' => esc_html__( 'Optional Sidebar three', 'clean-business-pro' )
		)
	);
	return apply_filters( 'sidebar_options', $options );
}


/**
 * Returns an array of metabox featured image options registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_metabox_featured_image_options() {
	$options['default'] = array(
		'id'	=> 'clean-business-featured-image',
		'value' => 'default',
		'label' => esc_html__( 'Default', 'clean-business-pro' ),
	);

	$all_sizes = clean_business_get_additional_image_sizes();

	foreach ($all_sizes as $key => $value) {
		$options[$key] = array(
			'id'	=> 'clean-business-featured-image',
			'value' => $key,
			'label' => esc_html( $key ).' ('.$value['width'].'x'.$value['height'].')'
		);

	}

	$options['full'] = array(
		'id'	=> 'clean-business-featured-image',
		'value'	=> 'full',
		'label' => esc_html__( 'Full Image', 'clean-business-pro' ),
	);

	$options['disabled'] = array(
		'id' 	=> 'clean-business-featured-image',
		'value' => 'disabled',
		'label' => esc_html__( 'Disable Image', 'clean-business-pro' )
	);

	return apply_filters( 'clean_business_single_post_image_layout_options', $options );
}

/**
 * Returns an array of featured content options registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_featured_content_layout_options() {
	$options = array(
		'layout-one' 	=> esc_html__( '1 column', 'clean-business-pro' ),
		'layout-two' 	=> esc_html__( '2 columns', 'clean-business-pro' ),
		'layout-three' 	=> esc_html__( '3 columns', 'clean-business-pro' ),
		'layout-four' 	=> esc_html__( '4 columns', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_featured_content_layout_options', $options );
}

/**
 * Returns an array of featured content show registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_featured_content_show() {
	$options = array(
		'excerpt' 		=> esc_html__( 'Show Excerpt', 'clean-business-pro' ),
		'full-content' 	=> esc_html__( 'Show Full Content', 'clean-business-pro' ),
		'hide-content' 	=> esc_html__( 'Hide Content', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_featured_content_show', $options );
}

/**
 * Returns an array of feature content types registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_featured_content_types() {
	$options = array(
		'demo-featured-content'     => esc_html__( 'Demo Featured Content', 'clean-business-pro' ),
		'featured-post-content'     => esc_html__( 'Featured Post Content', 'clean-business-pro' ),
		'featured-page-content'     => esc_html__( 'Featured Page Content', 'clean-business-pro' ),
		'featured-category-content' => esc_html__( 'Featured Category Content', 'clean-business-pro' ),
		'featured-image-content'    => esc_html__( 'Featured Image Content', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_featured_content_types', $options );
}


/**
 * Returns an array of featured content background image positions
 *
 * @since Clean Business 1.0
 */
function clean_business_featured_content_bg_display_positions() {
	$options = array(
		'top'    => esc_html__( 'Top', 'clean-business-pro' ),
		'bottom' => esc_html__( 'Bottom', 'clean-business-pro' ),
	);
	return apply_filters( 'clean_business_featured_content_bg_display_positions', $options );
}


/**
 * Returns an array of featured content background repeat options
 *
 * @since Clean Business 1.0
 */
function clean_business_featured_content_bg_repeat_options() {
	 $options = array(
		'no-repeat' => esc_html__( 'No repeat', 'clean-business-pro' ),
		'tile'      => esc_html__( 'Tile', 'clean-business-pro' ),
	);
	return apply_filters( 'clean_business_featured_content_bg_repeat_options', $options );
}


/**
 * Returns an array of featured content background attachment options
 *
 * @since Clean Business 1.0
 */
function clean_business_featured_content_bg_attachment_options() {
	$options = array(
		'scroll' => esc_html__( 'Scroll', 'clean-business-pro' ),
		'fixed'  => esc_html__( 'Fixed', 'clean-business-pro' ),
	);
	return apply_filters( 'clean_business_featured_content_bg_attachment_options', $options );
}

/**
 * Returns an array of slider layout options registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_featured_slider_options() {
	$options = array(
		'homepage' 		=> esc_html__( 'Homepage / Frontpage', 'clean-business-pro' ),
		'entire-site' 	=> esc_html__( 'Entire Site', 'clean-business-pro' ),
		'disabled'		=> esc_html__( 'Disabled', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_featured_slider_options', $options );
}

/**
 * Returns an array of feature slider types registered for fabulous fluid.
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_featured_slider_types() {
	$options = array(
		'demo-featured-slider'     => esc_html__( 'Demo Featured Slider', 'clean-business-pro' ),
		'featured-post-slider'     => esc_html__( 'Featured Post Slider', 'clean-business-pro' ),
		'featured-page-slider'     => esc_html__( 'Featured Page Slider', 'clean-business-pro' ),
		'featured-category-slider' => esc_html__( 'Featured Category Slider', 'clean-business-pro' ),
		'featured-image-slider'    => esc_html__( 'Featured Image Slider', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_featured_slider_types', $options );
}


/**
 * Returns an array of feature slider transition effects
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_featured_slider_transition_effects() {
	$options = array(
		'fade'  => esc_html__( 'Fade', 'clean-business-pro' ),
		'slide' => esc_html__( 'Slide', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_featured_slider_transition_effects', $options );
}


/**
 * Returns an array of content and slider layout options
 *
 * @since Clean Business 1.0
 */
function clean_business_featured_slider_content_options() {
	$options = array(
		'homepage' 		=> esc_html__( 'Homepage / Frontpage', 'clean-business-pro' ),
		'entire-site' 	=> esc_html__( 'Entire Site', 'clean-business-pro' ),
		'disabled'		=> esc_html__( 'Disabled', 'clean-business-pro' ),
	);

	return apply_filters( 'clean_business_featured_slider_content_options', $options );
}


/**
 * Returns list of social icons currently supported
 *
 * @since Clean Business 1.0
*/
function clean_business_get_social_icons_list() {
	$options = array(
		'facebook_link'    => array(
			'class' => 'facebook',
			'label' => esc_html__( 'Facebook', 'clean-business-pro' )
		),
		'twitter_link'     => array(
			'class' => 'twitter',
			'label' => esc_html__( 'Twitter', 'clean-business-pro' )
		),
		'googleplus_link'  => array(
			'class' => 'google-plus',
			'label' => esc_html__( 'Googleplus', 'clean-business-pro' )
		),
		'email_link'       => array(
			'class' => 'envelope',
			'label' => esc_html__( 'Email', 'clean-business-pro' )
		),
		'feed_link'        => array(
			'class' => 'rss',
			'label' => esc_html__( 'Feed', 'clean-business-pro' )
		),
		'wordpress_link'   => array(
			'class' => 'wordpress',
			'label' => esc_html__( 'WordPress', 'clean-business-pro' )
		),
		'github_link'      => array(
			'class' => 'github',
			'label' => esc_html__( 'GitHub', 'clean-business-pro' )
		),
		'linkedin_link'    => array(
			'class' => 'linkedin',
			'label' => esc_html__( 'LinkedIn', 'clean-business-pro' )
		),
		'pinterest_link'   => array(
			'class' => 'pinterest',
			'label' => esc_html__( 'Pinterest', 'clean-business-pro' )
		),
		'flickr_link'      => array(
			'class' => 'flickr',
			'label' => esc_html__( 'Flickr', 'clean-business-pro' )
		),
		'vimeo_link'       => array(
			'class' => 'vimeo',
			'label' => esc_html__( 'Vimeo', 'clean-business-pro' )
		),
		'youtube_link'     => array(
			'class' => 'youtube',
			'label' => esc_html__( 'YouTube', 'clean-business-pro' )
		),
		'tumblr_link'      => array(
			'class' => 'tumblr',
			'label' => esc_html__( 'Tumblr', 'clean-business-pro' )
		),
		'instagram_link'   => array(
			'class' => 'instagram',
			'label' => esc_html__( 'Instagram', 'clean-business-pro' )
		),
		// 'polldaddy_link'   => array(
		// 	'class' => 'polldaddy',
		// 	'label' => esc_html__( 'PollDaddy', 'clean-business-pro' )
		// ),
		'codepen_link'     => array(
			'class' => 'codepen',
			'label' => esc_html__( 'CodePen', 'clean-business-pro' )
		),
		// 'path_link'        => array(
		// 	'class' => 'path',
		// 	'label' => esc_html__( 'Path', 'clean-business-pro' )
		// ),
		'dribbble_link'    => array(
			'class' => 'dribbble',
			'label' => esc_html__( 'Dribbble', 'clean-business-pro' )
		),
		'skype_link'       => array(
			'class' => 'skype',
			'label' => esc_html__( 'Skype', 'clean-business-pro' )
		),
		'digg_link'        => array(
			'class' => 'digg',
			'label' => esc_html__( 'Digg', 'clean-business-pro' )
		),
		'reddit_link'      => array(
			'class' => 'reddit',
			'label' => esc_html__( 'Reddit', 'clean-business-pro' )
		),
		'stumbleupon_link' => array(
			'class' => 'stumbleupon',
			'label' => esc_html__( 'Stumbleupon', 'clean-business-pro' )
		),
		'pocket_link'      => array(
			'class' => 'get-pocket',
			'label' => esc_html__( 'Pocket', 'clean-business-pro' ),
		),
		'dropbox_link'     => array(
			'class' => 'dropbox',
			'label' => esc_html__( 'DropBox', 'clean-business-pro' ),
		),
		'spotify_link'     => array(
			'class' => 'spotify',
			'label' => esc_html__( 'Spotify', 'clean-business-pro' ),
		),
		'foursquare_link'  => array(
			'class' => 'foursquare',
			'label' => esc_html__( 'Foursquare', 'clean-business-pro' ),
		),
		'twitch_link'      => array(
			'class' => 'twitch',
			'label' => esc_html__( 'Twitch', 'clean-business-pro' ),
		),
		'website_link'     => array(
			'class' => 'globe',
			'label' => esc_html__( 'Website', 'clean-business-pro' ),
		),
		'phone_link'       => array(
			'class' => 'mobile',
			'label' => esc_html__( 'Phone', 'clean-business-pro' ),
		),
		'handset_link'     => array(
			'class' => 'phone',
			'label' => esc_html__( 'Handset', 'clean-business-pro' ),
		),
		'cart_link'        => array(
			'class' => 'shopping-cart',
			'label' => esc_html__( 'Cart', 'clean-business-pro' ),
		),
		'cloud_link'       => array(
			'class' => 'cloud',
			'label' => esc_html__( 'Cloud', 'clean-business-pro' ),
		),
		'link_link'        => array(
			'class' => 'link',
			'label' => esc_html__( 'Link', 'clean-business-pro' ),
		),
	);

	return apply_filters( 'clean_business_social_icons_list', $options );
}


/**
 * Checks if there are options already present from Clean Business Pro free version and adds it to the Clean Business Pro theme
 *
 * @since Clean Business Pro 1.0
 * @hook after_theme_switch
 */
function clean_business_setup_options() {
	if ( $clean_business_free_options = get_option ( 'theme_mods_clean-business' ) ) {
		foreach( $clean_business_free_options as $key => $value ) {
			if ( ! get_theme_mod( $key ) ) {
				set_theme_mod( $key, $value );
			}
		}
	}
}
add_action('after_switch_theme', 'clean_business_setup_options');
