<?php
/**
 * Adding support for WooCommerce Plugin
 */

if ( ! class_exists( 'woocommerce' ) ) {
    // Bail early if WooCommerce Plugin is not installed
    return;
}

if ( ! function_exists( 'clean_business_woocommerce_setup' ) ) :
    /**
     * Sets up support for various WooCommerce features.
     */
    function clean_business_woocommerce_setup() {
        add_theme_support( 'woocommerce' );

        $disable_product_gallery_zoom = apply_filters( 'clean_business_get_option', 'disable_product_gallery_zoom' );

        if ( ! $disable_product_gallery_zoom ) {
            add_theme_support('wc-product-gallery-zoom');
        }

        $disable_product_gallery_lightbox = apply_filters( 'clean_business_get_option', 'disable_product_gallery_lightbox' );

        if ( ! $disable_product_gallery_lightbox ) {
            add_theme_support('wc-product-gallery-lightbox');
        }

        $disable_product_gallery_slider = apply_filters( 'clean_business_get_option', 'disable_product_gallery_slider' );

        if ( ! $disable_product_gallery_slider ) {
            add_theme_support('wc-product-gallery-slider');
        }
    }
endif; //clean_business_woocommerce_setup
add_action( 'after_setup_theme', 'clean_business_woocommerce_setup' );

/**
 * Add/remove actions
 */
function clean_business_woo_actions() {
    remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
    remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);
    add_action('woocommerce_before_main_content', 'clean_business_wc_wrapper_start', 10);
    add_action('woocommerce_after_main_content', 'clean_business_wc_wrapper_end', 10);
}
add_action('wp','clean_business_woo_actions');

/**
 * Theme wrappers
 */
function clean_business_wc_wrapper_start() {
    echo '<div id="primary" class="content-area col-md-8">';
        echo '<main id="main" class="site-main" role="main">';
}

function clean_business_wc_wrapper_end() {
        echo '</main>';
    echo '</div>';
}

function clean_business_woocommerce_options( $wp_customize ) {
    $defaults = clean_business_get_default_theme_options();
    
    $wp_customize->add_setting( 'woocommerce_layout', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['woocommerce_layout'],
        'sanitize_callback' => 'clean_business_sanitize_select',
    ) );

    $wp_customize->add_control( 'woocommerce_layout', array(
		'choices'  => clean_business_layouts(),
		'label'    => esc_html__( 'Woocommerce Layout', 'clean-business-pro' ),
		'section'  => 'clean_business_layout',
		'settings' => 'woocommerce_layout',
		'type'     => 'select',
    ) );

    // WooCommerce Options
    $wp_customize->add_section( 'clean_business_woocommerce_options', array(
        'title'       => esc_html__( 'WooCommerce Options', 'clean-business-pro' ),
        'priority'    => 218,
        'panel'       => 'clean_business_theme_options',
        'description' => esc_html__( 'Since these options are added via theme support, you will need to save and refresh the customizer to view the full effect.', 'clean-business-pro' ),
    ) );

    $wp_customize->add_setting( 'disable_product_gallery_zoom', array(
        'default'           => $defaults['disable_product_gallery_zoom'],
        'sanitize_callback' => 'clean_business_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'disable_product_gallery_zoom', array(
        'label'     => esc_html__( 'Check to disable Product Gallery Zoom', 'clean-business-pro' ),
        'section'   => 'clean_business_woocommerce_options',
        'type'      => 'checkbox',
    ) );

    $wp_customize->add_setting( 'disable_product_gallery_lightbox', array(
        'default'           => $defaults['disable_product_gallery_lightbox'],
        'sanitize_callback' => 'clean_business_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'disable_product_gallery_lightbox', array(
        'label'     => esc_html__( 'Check to disable Product Gallery Lightbox', 'clean-business-pro' ),
        'section'   => 'clean_business_woocommerce_options',
        'type'      => 'checkbox',
    ) );

    $wp_customize->add_setting( 'disable_product_gallery_slider', array(
        'default'           => $defaults['disable_product_gallery_slider'],
        'sanitize_callback' => 'clean_business_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'disable_product_gallery_slider', array(
        'label'     => esc_html__( 'Check to disable Product Gallery Slider', 'clean-business-pro' ),
        'section'   => 'clean_business_woocommerce_options',
        'type'      => 'checkbox',
    ) );
}
add_action( 'customize_register', 'clean_business_woocommerce_options' );